==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/dir_0f36e20d213a0f76e1e4d5514a7e3ff2.js <==
var dir_0f36e20d213a0f76e1e4d5514a7e3ff2 =
[
    [ "PassClear", "dir_759c875c028e9b13a56dbd9fc6c9ee27.html", "dir_759c875c028e9b13a56dbd9fc6c9ee27" ],
    [ "PassCompute", "dir_6d493e738aee73d3c4cb4f524c3c0834.html", "dir_6d493e738aee73d3c4cb4f524c3c0834" ],
    [ "PassDepthCopy", "dir_d2457df6274e66c90b10ef07836a886a.html", "dir_d2457df6274e66c90b10ef07836a886a" ],
    [ "PassIblSpecular", "dir_9784d098f8274c1210ccb04a0081b95e.html", "dir_9784d098f8274c1210ccb04a0081b95e" ],
    [ "PassMipmap", "dir_05df85a03f50b16e5b92c67653862718.html", "dir_05df85a03f50b16e5b92c67653862718" ],
    [ "PassQuad", "dir_e7dd9b66172cccbed3cdbf44d47bc0cc.html", "dir_e7dd9b66172cccbed3cdbf44d47bc0cc" ],
    [ "PassScene", "dir_2cd752efc320c171603e99f3a7ae3fa3.html", "dir_2cd752efc320c171603e99f3a7ae3fa3" ],
    [ "PassShadows", "dir_e00e40535794c4f8f6c827aa9e939fe0.html", "dir_e00e40535794c4f8f6c827aa9e939fe0" ],
    [ "PassStencil", "dir_b40f8a973276e2e8d1700bae5ae6340f.html", "dir_b40f8a973276e2e8d1700bae5ae6340f" ],
    [ "PassTargetBarrier", "dir_2176e09fd72fbc604f2fc324ce1abe00.html", "dir_2176e09fd72fbc604f2fc324ce1abe00" ],
    [ "PassUav", "dir_01fee6b4718319771aa54ab43cf5f9be.html", "dir_01fee6b4718319771aa54ab43cf5f9be" ],
    [ "OgreCompositorPass.h", "_ogre_compositor_pass_8h.html", "_ogre_compositor_pass_8h" ],
    [ "OgreCompositorPassDef.h", "_ogre_compositor_pass_def_8h.html", "_ogre_compositor_pass_def_8h" ],
    [ "OgreCompositorPassProvider.h", "_ogre_compositor_pass_provider_8h.html", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/dir_0f36e20d213a0f76e1e4d5514a7e3ff2.js <==
var dir_0f36e20d213a0f76e1e4d5514a7e3ff2 =
[
    [ "PassClear", "dir_759c875c028e9b13a56dbd9fc6c9ee27.html", "dir_759c875c028e9b13a56dbd9fc6c9ee27" ],
    [ "PassCompute", "dir_6d493e738aee73d3c4cb4f524c3c0834.html", "dir_6d493e738aee73d3c4cb4f524c3c0834" ],
    [ "PassDepthCopy", "dir_d2457df6274e66c90b10ef07836a886a.html", "dir_d2457df6274e66c90b10ef07836a886a" ],
    [ "PassIblSpecular", "dir_9784d098f8274c1210ccb04a0081b95e.html", "dir_9784d098f8274c1210ccb04a0081b95e" ],
    [ "PassMipmap", "dir_05df85a03f50b16e5b92c67653862718.html", "dir_05df85a03f50b16e5b92c67653862718" ],
    [ "PassQuad", "dir_e7dd9b66172cccbed3cdbf44d47bc0cc.html", "dir_e7dd9b66172cccbed3cdbf44d47bc0cc" ],
    [ "PassScene", "dir_2cd752efc320c171603e99f3a7ae3fa3.html", "dir_2cd752efc320c171603e99f3a7ae3fa3" ],
    [ "PassShadows", "dir_e00e40535794c4f8f6c827aa9e939fe0.html", "dir_e00e40535794c4f8f6c827aa9e939fe0" ],
    [ "PassStencil", "dir_b40f8a973276e2e8d1700bae5ae6340f.html", "dir_b40f8a973276e2e8d1700bae5ae6340f" ],
    [ "PassTargetBarrier", "dir_2176e09fd72fbc604f2fc324ce1abe00.html", "dir_2176e09fd72fbc604f2fc324ce1abe00" ],
    [ "PassUav", "dir_01fee6b4718319771aa54ab43cf5f9be.html", "dir_01fee6b4718319771aa54ab43cf5f9be" ],
    [ "PassWarmUp", "dir_9154b4a4ec4d8d2418c86cadca649fe5.html", "dir_9154b4a4ec4d8d2418c86cadca649fe5" ],
    [ "OgreCompositorPass.h", "_ogre_compositor_pass_8h.html", "_ogre_compositor_pass_8h" ],
    [ "OgreCompositorPassDef.h", "_ogre_compositor_pass_def_8h.html", "_ogre_compositor_pass_def_8h" ],
    [ "OgreCompositorPassProvider.h", "_ogre_compositor_pass_provider_8h.html", null ]
];
